@@ -32,6 +32,8 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
+#include <gdk-pixbuf/gdk-pixbuf-macros.h>
+
 G_BEGIN_DECLS
 
 /**
@@ -213,50 +215,67 @@ typedef enum {
         GDK_PIXBUF_ERROR_INCOMPLETE_ANIMATION
 } GdkPixbufError;
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GQuark gdk_pixbuf_error_quark (void);
 
 
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GType gdk_pixbuf_get_type (void) G_GNUC_CONST;
 
 /* Reference counting */
 
 #ifndef GDK_PIXBUF_DISABLE_DEPRECATED
-G_DEPRECATED_FOR(g_object_ref)
+GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_ref)
 GdkPixbuf *gdk_pixbuf_ref      (GdkPixbuf *pixbuf);
-G_DEPRECATED_FOR(g_object_unref)
+GDK_PIXBUF_DEPRECATED_IN_2_0_FOR(g_object_unref)
 void       gdk_pixbuf_unref    (GdkPixbuf *pixbuf);
 #endif
 
 /* GdkPixbuf accessors */
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkColorspace gdk_pixbuf_get_colorspace      (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 int           gdk_pixbuf_get_n_channels      (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 gboolean      gdk_pixbuf_get_has_alpha       (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 int           gdk_pixbuf_get_bits_per_sample (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 guchar       *gdk_pixbuf_get_pixels          (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 int           gdk_pixbuf_get_width           (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 int           gdk_pixbuf_get_height          (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_ALL
 int           gdk_pixbuf_get_rowstride       (const GdkPixbuf *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_2_26
 gsize         gdk_pixbuf_get_byte_length     (const GdkPixbuf *pixbuf);
 
+GDK_PIXBUF_AVAILABLE_IN_2_26
 guchar       *gdk_pixbuf_get_pixels_with_length (const GdkPixbuf *pixbuf,
                                                  guint           *length);
 
+GDK_PIXBUF_AVAILABLE_IN_2_32
 const guint8* gdk_pixbuf_read_pixels         (const GdkPixbuf  *pixbuf);
+GDK_PIXBUF_AVAILABLE_IN_2_32
 GBytes *      gdk_pixbuf_read_pixel_bytes    (const GdkPixbuf  *pixbuf);
 
 
 
 /* Create a blank pixbuf with an optimal rowstride and a new buffer */
+
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new (GdkColorspace colorspace, gboolean has_alpha, int bits_per_sample,
 			   int width, int height);
 
 /* Copy a pixbuf */
-
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_copy (const GdkPixbuf *pixbuf);
 
 /* Create a pixbuf which points to the pixels of another pixbuf */
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
                                      int        src_x,
                                      int        src_y,
@@ -274,25 +293,31 @@ GdkPixbuf *gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
 #endif
 #endif
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new_from_file (const char *filename,
                                      GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_4
 GdkPixbuf *gdk_pixbuf_new_from_file_at_size (const char *filename,
 					     int         width, 
 					     int         height,
 					     GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_6
 GdkPixbuf *gdk_pixbuf_new_from_file_at_scale (const char *filename,
 					      int         width, 
 					      int         height,
 					      gboolean    preserve_aspect_ratio,
 					      GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_26
 GdkPixbuf *gdk_pixbuf_new_from_resource (const char *resource_path,
 					 GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_26
 GdkPixbuf *gdk_pixbuf_new_from_resource_at_scale (const char *resource_path,
 						  int         width,
 						  int         height,
 						  gboolean    preserve_aspect_ratio,
 						  GError    **error);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new_from_data (const guchar *data,
 				     GdkColorspace colorspace,
 				     gboolean has_alpha,
@@ -302,17 +327,19 @@ GdkPixbuf *gdk_pixbuf_new_from_data (const guchar *data,
 				     GdkPixbufDestroyNotify destroy_fn,
 				     gpointer destroy_fn_data);
 
+GDK_PIXBUF_AVAILABLE_IN_2_32
 GdkPixbuf *gdk_pixbuf_new_from_bytes (GBytes *data,
 				      GdkColorspace colorspace,
 				      gboolean has_alpha,
 				      int bits_per_sample,
 				      int width, int height,
 				      int rowstride);
- 
+
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new_from_xpm_data (const char **data);
 
 #ifndef GDK_PIXBUF_DISABLE_DEPRECATED
-G_DEPRECATED
+GDK_PIXBUF_DEPRECATED_IN_2_32
 GdkPixbuf* gdk_pixbuf_new_from_inline	(gint          data_length,
 					 const guint8 *data,
 					 gboolean      copy_pixels,
@@ -320,6 +347,7 @@ GdkPixbuf* gdk_pixbuf_new_from_inline	(gint          data_length,
 #endif
 
 /* Mutations */
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void       gdk_pixbuf_fill              (GdkPixbuf    *pixbuf,
                                          guint32       pixel);
 
@@ -333,12 +361,14 @@ void       gdk_pixbuf_fill              (GdkPixbuf    *pixbuf,
 #endif
 #endif
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 gboolean gdk_pixbuf_save           (GdkPixbuf  *pixbuf, 
                                     const char *filename, 
                                     const char *type, 
                                     GError    **error,
                                     ...) G_GNUC_NULL_TERMINATED;
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 gboolean gdk_pixbuf_savev          (GdkPixbuf  *pixbuf, 
                                     const char *filename, 
                                     const char *type,
@@ -372,6 +402,7 @@ typedef gboolean (*GdkPixbufSaveFunc)   (const gchar *buf,
 					 GError **error,
 					 gpointer data);
 
+GDK_PIXBUF_AVAILABLE_IN_2_4
 gboolean gdk_pixbuf_save_to_callback    (GdkPixbuf  *pixbuf,
 					 GdkPixbufSaveFunc save_func,
 					 gpointer user_data,
@@ -379,6 +410,7 @@ gboolean gdk_pixbuf_save_to_callback    (GdkPixbuf  *pixbuf,
 					 GError    **error,
 					 ...) G_GNUC_NULL_TERMINATED;
 
+GDK_PIXBUF_AVAILABLE_IN_2_4
 gboolean gdk_pixbuf_save_to_callbackv   (GdkPixbuf  *pixbuf, 
 					 GdkPixbufSaveFunc save_func,
 					 gpointer user_data,
@@ -389,6 +421,7 @@ gboolean gdk_pixbuf_save_to_callbackv   (GdkPixbuf  *pixbuf,
 
 /* Saving into a newly allocated char array */
 
+GDK_PIXBUF_AVAILABLE_IN_2_4
 gboolean gdk_pixbuf_save_to_buffer      (GdkPixbuf  *pixbuf,
 					 gchar     **buffer,
 					 gsize      *buffer_size,
@@ -396,6 +429,7 @@ gboolean gdk_pixbuf_save_to_buffer      (GdkPixbuf  *pixbuf,
 					 GError    **error,
 					 ...) G_GNUC_NULL_TERMINATED;
 
+GDK_PIXBUF_AVAILABLE_IN_2_4
 gboolean gdk_pixbuf_save_to_bufferv     (GdkPixbuf  *pixbuf,
 					 gchar     **buffer,
 					 gsize      *buffer_size,
@@ -404,18 +438,22 @@ gboolean gdk_pixbuf_save_to_bufferv     (GdkPixbuf  *pixbuf,
 					 char      **option_values,
 					 GError    **error);
 
+GDK_PIXBUF_AVAILABLE_IN_2_14
 GdkPixbuf *gdk_pixbuf_new_from_stream   (GInputStream   *stream,
 					 GCancellable   *cancellable,
                                          GError        **error);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void gdk_pixbuf_new_from_stream_async (GInputStream        *stream,
 				       GCancellable        *cancellable,
 				       GAsyncReadyCallback  callback,
 				       gpointer             user_data);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_new_from_stream_finish (GAsyncResult  *async_result,
 					      GError       **error);
 
+GDK_PIXBUF_AVAILABLE_IN_2_14
 GdkPixbuf *gdk_pixbuf_new_from_stream_at_scale   (GInputStream   *stream,
                                                   gint            width,
                                                   gint            height,
@@ -423,6 +461,7 @@ GdkPixbuf *gdk_pixbuf_new_from_stream_at_scale   (GInputStream   *stream,
 						  GCancellable   *cancellable,
                                                   GError        **error);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void gdk_pixbuf_new_from_stream_at_scale_async (GInputStream        *stream,
 						gint                 width,
 						gint                 height,
@@ -431,6 +470,7 @@ void gdk_pixbuf_new_from_stream_at_scale_async (GInputStream        *stream,
 						GAsyncReadyCallback  callback,
 						gpointer             user_data);
 
+GDK_PIXBUF_AVAILABLE_IN_2_14
 gboolean   gdk_pixbuf_save_to_stream    (GdkPixbuf      *pixbuf,
                                          GOutputStream  *stream,
                                          const char     *type,
@@ -438,6 +478,7 @@ gboolean   gdk_pixbuf_save_to_stream    (GdkPixbuf      *pixbuf,
                                          GError        **error,
                                          ...);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void gdk_pixbuf_save_to_stream_async (GdkPixbuf           *pixbuf,
 				      GOutputStream       *stream,
 				      const gchar         *type,
@@ -446,14 +487,36 @@ void gdk_pixbuf_save_to_stream_async (GdkPixbuf           *pixbuf,
 				      gpointer             user_data,
 				      ...);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 gboolean gdk_pixbuf_save_to_stream_finish (GAsyncResult  *async_result,
 					   GError       **error);
 
+GDK_PIXBUF_AVAILABLE_IN_2_36
+void gdk_pixbuf_save_to_streamv_async (GdkPixbuf           *pixbuf,
+                                       GOutputStream       *stream,
+                                       const gchar         *type,
+                                       gchar              **option_keys,
+                                       gchar              **option_values,
+                                       GCancellable        *cancellable,
+                                       GAsyncReadyCallback  callback,
+                                       gpointer             user_data);
+
+GDK_PIXBUF_AVAILABLE_IN_2_36
+gboolean gdk_pixbuf_save_to_streamv (GdkPixbuf      *pixbuf,
+                                     GOutputStream  *stream,
+                                     const char     *type,
+                                     char          **option_keys,
+                                     char          **option_values,
+                                     GCancellable   *cancellable,
+                                     GError        **error);
+
 /* Adding an alpha channel */
+GDK_PIXBUF_AVAILABLE_IN_ALL
 GdkPixbuf *gdk_pixbuf_add_alpha (const GdkPixbuf *pixbuf, gboolean substitute_color,
 				 guchar r, guchar g, guchar b);
 
 /* Copy an area of a pixbuf onto another one */
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void gdk_pixbuf_copy_area (const GdkPixbuf *src_pixbuf,
 			   int src_x, int src_y,
 			   int width, int height,
@@ -461,16 +524,20 @@ void gdk_pixbuf_copy_area (const GdkPixbuf *src_pixbuf,
 			   int dest_x, int dest_y);
 
 /* Brighten/darken and optionally make it pixelated-looking */
+GDK_PIXBUF_AVAILABLE_IN_ALL
 void gdk_pixbuf_saturate_and_pixelate (const GdkPixbuf *src,
                                        GdkPixbuf       *dest,
                                        gfloat           saturation,
                                        gboolean         pixelate);
 
 /* Transform an image to agree with its embedded orientation option / tag */
+GDK_PIXBUF_AVAILABLE_IN_2_12
 GdkPixbuf *gdk_pixbuf_apply_embedded_orientation (GdkPixbuf *src);
 
+GDK_PIXBUF_AVAILABLE_IN_ALL
 const gchar * gdk_pixbuf_get_option (GdkPixbuf   *pixbuf,
                                               const gchar *key);
+GDK_PIXBUF_AVAILABLE_IN_2_32
 GHashTable * gdk_pixbuf_get_options (GdkPixbuf   *pixbuf);
 
 
