@@ -45,8 +45,12 @@ Library version numbers.
 
 #define GDK_PIXBUF_MAJOR (2)
 #define GDK_PIXBUF_MINOR (35)
-#define GDK_PIXBUF_MICRO (1)
-#define GDK_PIXBUF_VERSION "2.35.1"
+#define GDK_PIXBUF_MICRO (2)
+#define GDK_PIXBUF_VERSION "2.35.2"
+
+#ifndef _GDK_PIXBUF_EXTERN
+#define _GDK_PIXBUF_EXTERN extern
+#endif
 
 /* We prefix variable declarations so they can
  * properly get exported/imported from Windows DLLs.
@@ -57,7 +61,7 @@ Library version numbers.
 #  else /* !GDK_PIXBUF_STATIC_COMPILATION */
 #    ifdef GDK_PIXBUF_C_COMPILATION
 #      ifdef DLL_EXPORT
-#        define GDK_PIXBUF_VAR __declspec(dllexport)
+#        define GDK_PIXBUF_VAR _GDK_PIXBUF_EXTERN
 #      else /* !DLL_EXPORT */
 #        define GDK_PIXBUF_VAR extern
 #      endif /* !DLL_EXPORT */
@@ -66,7 +70,7 @@ Library version numbers.
 #    endif /* !GDK_PIXBUF_C_COMPILATION */
 #  endif /* !GDK_PIXBUF_STATIC_COMPILATION */
 #else /* !G_PLATFORM_WIN32 */
-#  define GDK_PIXBUF_VAR extern
+#  define GDK_PIXBUF_VAR _GDK_PIXBUF_EXTERN
 #endif /* !G_PLATFORM_WIN32 */
 
 /**
